@@ -2,7 +2,7 @@
 Functions to search for text in a pandas dataframe column.
 """
 
-from .explore_utils import search, check_missing_values
+from explore.explore_utils import search, check_missing_values
 
 __all__ = ['search',
            'check_missing_values']
\ No newline at end of file
