@@ -3,7 +3,7 @@ Functions to modify a pandas dataframe e.g. rename columns, to
 standardise column headers. or to fill missing values with a string.
 """
 
-from .dataframe_utils import rename_column, standardise_column_headers, fill_missing
+from preprocess_dataframe.dataframe_utils import rename_column, standardise_column_headers, fill_missing
 
 __all__ = ['rename_column',
            'standardise_column_headers',
